# -*- coding: utf-8 -*-
#########################################################################
#
# Copyright 2015-2018, GeoSolutions Sas.
# All rights reserved.
#
# This source code is licensed under the BSD-style license found in the
# LICENSE file in the root directory of this source tree.
#
#########################################################################
default_app_config = "geonode_mapstore_client.apps.AppConfig"


class GeoNodeMapstore2Exception(Exception):
    """Base class for exceptions in this module."""
    pass
